==> authd_0.1.tar.xz: authd-0.1/README.md <==
# Welcome to Authentication daemon for external Broker

[actions-image]: https://github.com/ubuntu/authd/actions/workflows/qa.yaml/badge.svg
[actions-url]: https://github.com/ubuntu/authd/actions?query=workflow%3AQA

[license-image]: https://img.shields.io/badge/License-GPL3.0-blue.svg

[codecov-image]: https://codecov.io/gh/ubuntu/authd/graph/badge.svg
[codecov-url]: https://codecov.io/gh/ubuntu/authd

[user-documentation-image]: https://pkg.go.dev/github.com/ubuntu/authd
[user-documentation-url]: https://pkg.go.dev/github.com/ubuntu/authd

[reference-documentation-image]: https://discouse.ubuntu.com/TODO
[reference-documentation-url]: https://discouse.ubuntu.com/TODO

[goreport-image]: https://goreportcard.com/badge/github.com/ubuntu/authd
[goreport-url]: https://goreportcard.com/report/github.com/ubuntu/authd

[![Code quality][actions-image]][actions-url]
[![License][license-image]](LICENSE)
[![Code coverage][codecov-image]][codecov-url]
[![User Documentation][user-documentation-image]][user-documentation-url]
[![Reference documentation][reference-documentation-image]][reference-documentation-url]
[![Go Report Card][goreport-image]][goreport-url]

This is the code repository for authd*, an authentication daemon for external Broker.

TODO: More general description about the project.

For general details, including [installation](TODO link to installation instruction) and [Getting started](TODO link to getting started instructions) guides, head over to our [PROJECT_TODO documentation](link to project documentation).

## Troubleshooting

TODO: Add details on how to debug this project, where to increase verbosity, how to find logs, how to run in debug mode.

## Get involved

This is an [open source](LICENSE) project and we warmly welcome community contributions, suggestions, and constructive feedback. If you're interested in contributing, please take a look at our [Contribution guidelines](CONTRIBUTING.md) first.

- to report an issue, please file a bug report against our repository, using a bug template.
- for suggestions and constructive feedback, report a feature request bug report, using the proposed template.

## Get in touch

We're friendly! We have a community forum at [https://discourse.ubuntu.com](https://discourse.ubuntu.com) where we discuss feature plans, development news, issues, updates and troubleshooting.

For news and updates, follow the [Ubuntu twitter account](https://twitter.com/ubuntu) and on [Facebook](https://www.facebook.com/ubuntu).

==> authd_0.2.tar.xz: authd-0.2/README.md <==
# Welcome to Authentication daemon for external Broker

[actions-image]: https://github.com/ubuntu/authd/actions/workflows/qa.yaml/badge.svg
[actions-url]: https://github.com/ubuntu/authd/actions?query=workflow%3AQA

[license-image]: https://img.shields.io/badge/License-GPL3.0-blue.svg

[codecov-image]: https://codecov.io/gh/ubuntu/authd/graph/badge.svg
[codecov-url]: https://codecov.io/gh/ubuntu/authd

[user-documentation-image]: https://pkg.go.dev/github.com/ubuntu/authd
[user-documentation-url]: https://pkg.go.dev/github.com/ubuntu/authd

[reference-documentation-image]: https://discouse.ubuntu.com/TODO
[reference-documentation-url]: https://discouse.ubuntu.com/TODO

[goreport-image]: https://goreportcard.com/badge/github.com/ubuntu/authd
[goreport-url]: https://goreportcard.com/report/github.com/ubuntu/authd

[![Code quality][actions-image]][actions-url]
[![License][license-image]](LICENSE)
[![Code coverage][codecov-image]][codecov-url]
[![User Documentation][user-documentation-image]][user-documentation-url]
[![Reference documentation][reference-documentation-image]][reference-documentation-url]
[![Go Report Card][goreport-image]][goreport-url]

This is the code repository for authd, an authentication daemon for cloud-based identity provider.

Authd is a versatile authentication service for Ubuntu, designed to seamlessly integrate with cloud identity providers like OpenID Connect and Entra ID. It offers a secure interface for system authentication, supporting cloud-based identity management. Authd features a modular structure, facilitating straightforward integration with different cloud services. This design aids in maintaining strong security and effective user authentication. It's well-suited for handling access to cloud identities, offering a balance of security and ease of use.

For general details, including [installation](TODO link to installation instruction) and [Getting started](TODO link to getting started instructions) guides, head over to our [PROJECT_TODO documentation](link to project documentation).

## Troubleshooting

TODO: Add details on how to debug this project, where to increase verbosity, how to find logs, how to run in debug mode.

## Get involved

This is an [open source](LICENSE) project and we warmly welcome community contributions, suggestions, and constructive feedback. If you're interested in contributing, please take a look at our [Contribution guidelines](CONTRIBUTING.md) first.

- to report an issue, please file a bug report against our repository, using a bug template.
- for suggestions and constructive feedback, report a feature request bug report, using the proposed template.

## Get in touch

We're friendly! We have a community forum at [https://discourse.ubuntu.com](https://discourse.ubuntu.com) where we discuss feature plans, development news, issues, updates and troubleshooting.

For news and updates, follow the [Ubuntu twitter account](https://twitter.com/ubuntu) and on [Facebook](https://www.facebook.com/ubuntu).
